# Python library and tools for VisionCar robot

[![PyPI version](https://badge.fury.io/py/visioncar.svg)](https://badge.fury.io/py/visioncar)

```bash
# install
pip3 install visioncar

# help
visioncar -h

# discover connected cars and operate using REPL
visioncar
```
